@@ -1,5 +1,5 @@
 package System::Command;
-$System::Command::VERSION = '1.116';
+$System::Command::VERSION = '1.118';
 use warnings;
 use strict;
 use 5.006;
@@ -309,6 +309,61 @@ sub spawn {
     return @{ $class->new(@cmd) }{qw( pid stdin stdout stderr )};
 }
 
+sub loop_on {
+    my $self = shift;
+
+    # handle options and defaults
+    my %args = (
+        stderr => sub { print STDERR shift },
+        @_
+    );
+    for my $which ( grep exists $args{$_}, qw( stdout stderr ) ) {
+        if ( $args{$which} ) {
+            croak "'$which' option must be a CODE reference"
+              if reftype $args{$which} ne 'CODE';
+        }
+        else {
+            delete $args{$which};
+        }
+    }
+
+    # create an object for the class method
+    if ( !ref $self ) {
+        die "'command' attribute required by loop_on when used as a class method"
+          if !exists $args{command};
+        $self = $self->new( @{ $args{command} } );
+    }
+
+    require IO::Select;
+    my $select = IO::Select->new( $self->stdout, $self->stderr );
+
+    local $/ = $args{input_record_separator}
+      if exists $args{input_record_separator};
+
+    # loop until end of streams
+    while ( my @ready = $select->can_read ) {
+        for my $fh (@ready) {
+            my $which = $fh == $self->stdout ? 'stdout' : 'stderr';
+            if ( defined( my $line = <$fh> ) ) {
+                my $ret = 1;
+                $ret = $args{$which}->($line)
+                  if exists $args{$which};
+                return if !$ret;
+            }
+            else {
+                $select->remove($fh);
+                $fh->close;
+            }
+        }
+    }
+
+    # close all pipes and wait for the child to terminate
+    $self->close;
+
+    # success in the Unix sense
+    return defined $self->exit && $self->exit == 0;
+}
+
 # delegate those to the reaper (when there's one)
 sub is_terminated {
     return $_[0]{options}{interactive}
@@ -537,6 +592,35 @@ attributes, in that order.
 
 (Added in version 1.01.)
 
+=head2 loop_on
+
+    $cmd->loop_on(
+        stdout => sub { ... },
+        stderr => sub { ... },
+    );
+
+This method calls the corresponding code references with each line
+produced on the standard output and errput of the command.
+
+If the C<stdout> or C<stderr> argument is not given, the default is to
+silently drop the data for C<stdout>, and to pass through (to STDERR)
+the data for C<stderr>. To prevent any processing, pass a false value
+to the parameter.
+
+For example, the following line will silently run the command to
+completion:
+
+    $cmd->loop_on( stderr => '' );
+
+The method blocks until the command is completed (or rather, until
+its output and errput handles have been closed), or until one of the
+callbacks returns a false value.
+
+The return value is true if the command exited with status 0, and false
+otherwise (i.e. the Unix traditional definition of success).
+
+(Added in version 1.117.)
+
 =head2 Accessors
 
 The attributes of a System::Command object are also accessible
@@ -707,7 +791,7 @@ L<http://search.cpan.org/dist/System-Command/>
 
 =head1 COPYRIGHT
 
-Copyright 2010-2015 Philippe Bruhat (BooK).
+Copyright 2010-2016 Philippe Bruhat (BooK).
 
 =head1 LICENSE
 
