@@ -1,5 +1,5 @@
 package System::Command::Reaper;
-$System::Command::Reaper::VERSION = '1.117';
+$System::Command::Reaper::VERSION = '1.118';
 use strict;
 use warnings;
 use 5.006;
@@ -58,7 +58,7 @@ sub _reap {
     my $pid = $self->{pid};
 
     # REPENT/THE END IS/EXTREMELY/FUCKING/NIGH
-    if ( my $reaped = waitpid( $pid, $flags ) and !exists $self->{exit} ) {
+    if ( !exists $self->{exit} and my $reaped = waitpid( $pid, $flags ) ) {
 
         # Well, it's a puzzle because, technically, you're not alive.
         my $zed = $reaped == $pid;
@@ -255,7 +255,7 @@ reaping) with code examples, which I then adapted to my needs.
 
 =head1 COPYRIGHT
 
-Copyright 2010-2015 Philippe Bruhat (BooK), all rights reserved.
+Copyright 2010-2016 Philippe Bruhat (BooK), all rights reserved.
 
 =head1 LICENSE
 
